@@ -14,9 +14,8 @@ FieldView::FieldView(ReversiGame &reversiGame, QWidget *parent) :
     QGraphicsView(parent),
     reversiGame_(reversiGame)
 {
-    scene_ = new ReversiScene(reversiGame_, parent->parentWidget());
+    scene_ = new ReversiScene(reversiGame_);
     setScene(scene_);
-    scene_->syncBoard();
 
     setMinimumSize(scene_->fieldWidth(), scene_->fieldHeight());
     setMaximumSize(scene_->fieldWidth(), scene_->fieldHeight());
