@@ -9,6 +9,7 @@
 
 #include "mainwindow.h"
 #include "centralwidget.h"
+#include "utils.h"
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
@@ -23,7 +24,6 @@ MainWindow::MainWindow(QWidget *parent)
 
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(slotOrientationChanged()));
     connect(&reversiGame_, SIGNAL(gameOver()), SLOT(slotGameOver()));
-    connect(&reversiGame_, SIGNAL(stepUnavailable()), SLOT(stepUnavailable()));
 
     slotNewGame();
 }
@@ -58,27 +58,11 @@ void MainWindow::slotNewGame()
 void MainWindow::slotGameOver()
 {
     QString info;
-    info = QString("Game over!\n White player %1; Black player %2.").arg(reversiGame_.score(White)).arg(reversiGame_.score(Black));
-#ifdef Q_WS_MAEMO_5
-    QMaemo5InformationBox::information(this, info, QMaemo5InformationBox::NoTimeout);
-#else
-    QMessageBox::information(this, "Qthello", info);
-#endif
+    info = QString(tr("Game over!\n White player %1; Black player %2.")).arg(reversiGame_.score(White)).arg(reversiGame_.score(Black));
+    showMessage(this, info);
     slotNewGame();
 }
 
-void MainWindow::stepUnavailable()
-{
-    static const char *players[] = {"White", "Black"};
-    QString info;
-    info = QString("%1 can't move. %2 turn.").arg(players[reversiGame_.currentPlayer()]).arg(players[reversiGame_.opponentPlayer()]);
-#ifdef Q_WS_MAEMO_5
-    QMaemo5InformationBox::information(this, info, QMaemo5InformationBox::NoTimeout);
-#else
-    QMessageBox::warning(this, "Qthello", info);
-#endif
-}
-
 void MainWindow::slotOrientationChanged()
 {
     centralWdgt->showInfoPanels();
