@@ -19,10 +19,6 @@ public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
-public slots:
-    void stepUnavailable();
-
-
 private:
     CentralWidget *centralWdgt;
     ReversiGame reversiGame_;
