@@ -31,7 +31,7 @@ ReversiScene::ReversiScene(ReversiGame &reversiGame):
     fieldHeight_ = FIELDSIZE * cellHeight_;
 
     connect(&reversiGame_, SIGNAL(stepComplete()), SLOT(slotStepComplete()));
-    connect(&reversiGame_, SIGNAL(newGame(bool)), SLOT(slotNewGame(bool)));
+    connect(&reversiGame_, SIGNAL(newGame(int)), SLOT(slotNewGame(int)));
     connect(animTimer_, SIGNAL(timeout()), SLOT(slotAnimationStep()));
 }
 
@@ -43,21 +43,29 @@ ReversiScene::~ReversiScene()
 
 void ReversiScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
+    //wait while animation running
+    if (animTimer_->isActive())
+        return;
+    currentPlayer_ = reversiGame_.currentPlayer();
+    //wait move of other player
+    if ((mode_ == 1 && currentPlayer_ != Black) || (mode_ == 2 && currentPlayer_ != White))
+        return;
     int x = int(event->scenePos().x() / cellWidth_);
     int y = int(event->scenePos().y() / cellHeight_);
-    currentPlayer_ = reversiGame_.currentPlayer();
+
     if (isNetworkMode_)
         emit playerStep(x, y);
     else
         reversiGame_.makeStep(x, y);
 }
 
-void ReversiScene::slotNewGame(bool networkGame)
+void ReversiScene::slotNewGame(int mode)
 {
     if (animTimer_->isActive())
         animTimer_->stop();
     currentPlayer_ = reversiGame_.currentPlayer();
-    isNetworkMode_ = networkGame;
+    mode_ = mode;
+    isNetworkMode_ = mode > 2;
     syncBoard();
 }
 
