@@ -34,7 +34,7 @@ private:
 
 private slots:
     void slotStepComplete();
-    void slotNewGame(bool);
+    void slotNewGame(int);
     void slotAnimationStep();
 
 private:
@@ -46,6 +46,7 @@ private:
     int fieldWidth_;
     int fieldHeight_;
     bool isNetworkMode_;
+    int mode_;
 
     //variables for animation
     QTimer *animTimer_;
